@@ -50,7 +50,7 @@ switch ($params['mode'])
 			$params['allow_notifications'] = empty($params['allow_notifications']) ? 0 : 1;
 			$params['notification_subject'] = '';
 			$params['notification_message'] = '';
-			$params['required_fields'] = implode(',', $params['required_fields']);
+			$params['required_fields'] = empty($params['required_fields']) ? '' : implode(',', $params['required_fields']);
 			$params['active'] = empty($params['active']) ? 0 : 1;
 
 			$query = "INSERT INTO ".cms_db_prefix()."module_gbook (
@@ -162,7 +162,7 @@ switch ($params['mode'])
 			$params['allow_notifications'] = empty($params['allow_notifications']) ? 0 : 1;
 			$params['notification_subject'] = '';
 			$params['notification_message'] = '';
-			$params['required_fields'] = implode(',', $params['required_fields']);
+			$params['required_fields'] = empty($params['required_fields']) ? '' : implode(',', $params['required_fields']);
 			$params['active'] = empty($params['active']) ? 0 : 1;
 			$query = "UPDATE " . cms_db_prefix() . "module_gbook SET 
 									name = ?, 
